@@ -29,7 +29,7 @@ run_job(
     }
 );
 
-1;
+exit;
 
 =head1 NAME
 
